## Description
<!-- Provide a clear and concise description of your changes -->

## Type of Change
<!-- Please check the one that applies to this PR using "x". -->
- [ ] 🐛 Bug fix (non-breaking change which fixes an issue)
- [ ] ✨ New feature (non-breaking change which adds functionality)
- [ ] 💥 Breaking change (fix or feature that would cause existing functionality to change)
- [ ] 📝 Documentation update
- [ ] 🎨 Style/UI update
- [ ] ♻️ Code refactoring
- [ ] 🚀 Performance improvement
- [ ] 🔧 Build/CI configuration change

## Related Issue
<!-- Please link to any related issues here using #issue-number -->
Fixes #

## Testing
<!-- Please describe the tests that you ran to verify your changes -->
- [ ] Unit Tests
- [ ] Integration Tests
- [ ] Manual Testing

### Test Configuration
- OS:
- Python version:
- CoralNet-Toolbox version:


## Screenshots (if appropriate)
<!-- Add screenshots here -->

## Checklist
<!-- Please check all items that apply using "x". -->
- [ ] My code follows the project's coding style
- [ ] I have added/updated necessary documentation
- [ ] All new and existing tests passed
- [ ] My changes generate no new warnings
- [ ] I have tested this on Windows/Linux/macOS (as applicable)

## Additional Notes
<!-- Add any other context about the PR here -->
